#!/bin/sh

# EvoMaintenance script
# Dependencies (all OS): git postgresql-client
# Dependencies (Debian): sudo

# version 0.3
# Copyright 2007-2018 Gregory Colpart <reg@evolix.fr>, Jérémy Lecour <jlecour@evolix.fr>, Evolix <info@evolix.fr>

test -f /etc/evomaintenance.cf && . /etc/evomaintenance.cf

[ -n "${HOSTNAME}" ]     || HOSTNAME=$(hostname)
[ -n "${EVOMAINTMAIL}" ] || EVOMAINTMAIL=evomaintenance-$(echo "${HOSTNAME}" | cut -d- -f1)@${REALM}
[ -n "${LOGFILE}" ]      || LOGFILE=/var/log/evomaintenance.log

PATH=${PATH}:/usr/sbin

WHO=$(LC_ALL=C who -m)
USER=$(echo ${WHO} | cut -d" " -f1)
IP=$(echo ${WHO} | cut -d" " -f6  | sed -e "s/^(// ; s/)$//")
BEGIN_DATE=$(echo ${WHO} | cut -d" " -f3,4,5)
BEGIN_YEAR=$(date "+%Y")

# "date --iso8601" is not available everywhere
NOW=$(date +"%Y-%m-%dT%H:%M:%S%z")

# details
echo "Please, enter details about your maintenance"
read TEXTE

if [ "${TEXTE}" = "" ]; then
    echo "no value..."
    exit 1
fi

# recapitulatif
echo "hostname = ${HOSTNAME}"
echo "user = ${USER}"
echo "IP = ${IP}"
echo "begin date = ${BEGIN_YEAR} ${BEGIN_DATE}"
echo "details = ${TEXTE}"

echo "To cancel, [Ctrl+C] else press [Enter]"
read enter

# write log
LOG_TEXTE=$(echo "${TEXTE}" | sed 's/"/\\\"/g')

echo "${NOW} hostname=\"${HOSTNAME}\" user=\"${USER}\" ip=\"${IP}\" begin_date=\"${BEGIN_YEAR} ${BEGIN_DATE}\" message=\"${LOG_TEXTE}\"" >> "${LOGFILE}"

# git commit
GIT_BIN=$(command -v git)

if test -x "${GIT_BIN}"; then
    export GIT_DIR=/etc/.git
    ${GIT_BIN} add .
    ${GIT_BIN} commit --all --message "${LOG_TEXTE}" --author="${USER} <${USER}@evolix.net>" --quiet
fi

# insert into PG
SQL_TEXTE=`echo "${TEXTE}" | sed "s/'/\\\\\\'/g ; s@/@\\\\\/@g ; s@\\&@et@g"`

echo "
INSERT INTO evomaint(hostname,userid,ipaddress,begin_date,end_date,details)
VALUES ('${HOSTNAME}','${USER}','${IP}','${BEGIN_YEAR} ${BEGIN_DATE}',now(),'${SQL_TEXTE}') " | \
    psql ${PGDB} ${PGTABLE} -h ${PGHOST}

# send mail
SENDMAIL=$(command -v sendmail)

cat /usr/share/scripts/evomaintenance.tpl | \
    sed -e "s/__TO__/${EVOMAINTMAIL}/ ; s/__HOSTNAME__/${HOSTNAME}/ ; s/__USER__/${USER}/ ; s/__BEGIN_DATE__/${BEGIN_YEAR} ${BEGIN_DATE}/ ; s/__TEXTE__/${TEXTE}/ ; s/__IP__/${IP}/ ; s/__FULLFROM__/${FULLFROM}/ ; s/__FROM__/${FROM}/ ; s/__URGENCYFROM__/${URGENCYFROM}/ ; s/__URGENCYTEL__/${URGENCYTEL}/" | \
    ${SENDMAIL} -oi -t -f ${FROM}
